#!/usr/bin/perl

use strict;
use HSPC::WebDB;
use HSPC::MT::PluginConfig::PP;

use constant PLUGIN_ID   => 'BT_BANKINTER';
use constant TEMPLATE_ID => 'BT_Norma19';

if (is_table_exists(table=>'vendor_pp_plugin') 
	&& is_table_exists(table=>'pp_plugin_dummy') )
{
	my $rows = 
	  select_hashrows(q|
			SELECT
				vendor_pp_plugin.vendor_id,
				vendor_pp_plugin.plugin_id,
				vendor_pp_plugin.is_active,
				vendor_pp_plugin.banner_text,
				pp_plugin.title,
				pp_plugin.is_autopay_supported
			FROM 
				vendor_pp_plugin, pp_plugin
			WHERE
				vendor_pp_plugin.plugin_id = pp_plugin.id AND
				vendor_pp_plugin.plugin_id = ?
		|, &PLUGIN_ID );

	my %config_map = (
		issuer_account     => 'issuer_account',
		issuer_agency      => 'issuer_agency',
		issuer_branch      => 'issuer_branch',
		issuer_code        => 'issuer_code',
		issuer_control_dig => 'issuer_control_dig',
		issuer_name        => 'issuer_name',
		opt_address_add    => 'opt_address_add',
		opt_field_tmpl_01  => 'opt_field_tmpl_1',
		opt_field_tmpl_02  => 'opt_field_tmpl_2',
		opt_field_tmpl_03  => 'opt_field_tmpl_3',
		opt_field_tmpl_04  => 'opt_field_tmpl_4',
		opt_field_tmpl_05  => 'opt_field_tmpl_5',
		opt_field_tmpl_06  => 'opt_field_tmpl_6',
		opt_field_tmpl_07  => 'opt_field_tmpl_7',
		opt_field_tmpl_08  => 'opt_field_tmpl_8',
		opt_field_tmpl_09  => 'opt_field_tmpl_9',
		opt_field_tmpl_10  => 'opt_field_tmpl_10',
		opt_field_tmpl_11  => 'opt_field_tmpl_11',
		opt_field_tmpl_12  => 'opt_field_tmpl_12',
		opt_field_tmpl_13  => 'opt_field_tmpl_13',
		opt_field_tmpl_14  => 'opt_field_tmpl_14',
		opt_field_tmpl_15  => 'opt_field_tmpl_15',
		opt_field_tmpl_16  => 'opt_field_tmpl_16',
	);

	exit 0 unless $rows;

	foreach my $plugin (@$rows) {
		my $config = 
		  select_hashrows(q|
				SELECT
					name, value
				FROM 
					pp_plugin_bankinter_config
				WHERE
					provider_id = ?
			|, $plugin->{vendor_id} );

		if ( $config && @$config ) {
	
			my $new_plugin = HSPC::MT::PluginConfig::PP->new();
	
			$new_plugin->vendor_id( $plugin->{vendor_id} );
			$new_plugin->is_active( $plugin->{is_active} );
			$new_plugin->plugin_type('PP');
			$new_plugin->name( $plugin->{title} );

			my $new_config = {};
			foreach my $c (@$config) {
				$new_config->{$config_map{$c->{name}}} = $c->{value};
			}

			$new_plugin->config_data( $new_config );
	
			$new_plugin->template_id( &TEMPLATE_ID );
	
			$new_plugin->banner_text( $plugin->{banner_text} );
	
			$new_plugin->is_direct( $plugin->{is_autopay_supported} );
			$new_plugin->save();
	
			if ($new_plugin->id()) {
				select_run(q|
					insert into plugin_pp_paytypes (config_id, type, template_id) values (?,?,?)|,
					$new_plugin->id(), 'BT_Norma19', 'BT_Norma19'
				);
			
				## upgrade orders payed by this plugin
				select_run(q|
					UPDATE
						ar_doc_rb, ar_doc
					SET
						ar_doc_rb.plugin_id = ? 
					WHERE
						ar_doc_rb.ar_doc_id = ar_doc.ar_doc_id 
						AND ar_doc.vendor = ?
						AND ar_doc_rb.plugin_id = ?|,
						$new_plugin->id(), $new_plugin->vendor_id(), &PLUGIN_ID );
	
				## upgrade batches generated by this plugin
				select_run(q|
					UPDATE
						bm_doc_batch
					SET
						plugin_id = ?
					WHERE
						vendor_id = ?
						AND plugin_id = ?|,
					$new_plugin->id(), $new_plugin->vendor_id(), &PLUGIN_ID
				);

				## Update TransLog
				select_run(q|
					UPDATE
						pp_trans_log, account
					SET
						pp_trans_log.plugin_id = ?
					WHERE
						pp_trans_log.account_no = account.account_no
						AND account.vendor = ?
						AND pp_trans_log.plugin_id = ?|,
						$new_plugin->id(), $new_plugin->vendor_id(), &PLUGIN_ID 
				);
			}
		}
	}
}

## update reseller config
select_run(
	q|UPDATE reseller_config_plugin SET plugin_id = ? WHERE plugin_id = ?|,
	&TEMPLATE_ID,
	&PLUGIN_ID
);

